/*
** Copyright (C) 08 Jun 1999 Jonas Munsin <jmunsin@iki.fi>
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
** 
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
** 
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software 
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

typedef struct {
	int elements_used;
	int elements_allocated;
	char **elements;
} cmd_v;

void add_option_to_cmd(cmd_v *, const char *);
void destroy_cmd(cmd_v *);
cmd_v *get_new_cmd(void);
void print_cmd(cmd_v *);
char *cmd_to_string(cmd_v *);
char *escape_graft_chars(const char *);
